'use strict';

var BG = chrome.extension.getBackgroundPage();

function loadOptions() {
  // Check or uncheck each option.
  optionalSettings = BG.getSettings();
  localizePage();
  if (!optionalSettings.show_advanced_options) {
    $('.advanced').hide();
  }
  if (optionalSettings && !optionalSettings.show_language_selector) {
    $(".languageSelector").hide();
  }

  var currTabIndex = getStorageCookie('adblock_optiontab_index');
  if (!currTabIndex) {
    currTabIndex = 0;
    setStorageCookie('adblock_optiontab_index', currTabIndex, THIRTY_MINUTES_IN_MILLISECONDS);
  }

  if (window.location &&
    window.location.search)
  {
    var searchQuery = parseUri.parseSearch(window.location.search);
    if (searchQuery &&
      searchQuery.tab)
    {
      currTabIndex = searchQuery.tab;
    }
  }

  $('#tabs').tabs({
      active: currTabIndex,
      activate: function (event, ui) {
          setStorageCookie('adblock_optiontab_index', ui.newTab.index(), THIRTY_MINUTES_IN_MILLISECONDS);
          if (!optionalSettings.show_advanced_options) {
            $('.advanced').hide();
          }
        },
    }).show();

  //initialze each tab
  generalInit();
  filtersInit();
  customizeInit();
  supportInit();
}

var language = '';
if ((typeof navigator.language !== 'undefined') &&
    navigator.language) {
  language = navigator.language.match(/^[a-z]+/i)[0];
}

function rightToLeft(language) {
  if (language === 'ar' || language === 'he') {
    $(window).resize(function () {
        if ($('.social').is(':hidden')) {
          $('#translation_credits').css({ margin: '0px 50%', width: '350px' });
          $('#paymentlink').css({ margin: '0px 50%', width: '350px' });
          $('#version_number').css({ margin: '20px 50%', width: '350px' });
        } else {
          $('#translation_credits').css('right', '0px');
          $('#paymentlink').css('right', '0px');
          $('#version_number').css({ right: '0px', padding: '0px' });
        }
      });

    $('li').css('float', 'right');
    $('#small_nav').css({ right: 'initial', left: '45px' });
    $('.ui-tabs .ui-tabs-nav li').css('float', 'right');
  } else {
    $('.ui-tabs .ui-tabs-nav li').css('float', 'left');
  }
}

function showMiniMenu(language) {
  $('#small_nav').click(function () {
      if ($('.ui-tabs-nav').is(':hidden')) {
        $('.ui-tabs .ui-tabs-nav li').css('float', 'none');
        $('.ui-tabs-nav').fadeIn('fast');
        if (language === 'ar' || language === 'he') {
          $('.ui-tabs-nav').css({ right: 'auto', left: '40px' });
        }
      } else
          $('.ui-tabs-nav').fadeOut('fast');
    });

  $(window).resize(function () {
      if ($('.ui-tabs-nav').is(':hidden') && $('#small_nav').is(':hidden')) {
        if (language === 'ar' || language === 'he') {
          $('.ui-tabs .ui-tabs-nav li').css('float', 'right');
          $('.ui-tabs-nav').css({ right: 'auto', left: 'auto' });
        } else {
          $('.ui-tabs .ui-tabs-nav li').css('float', 'left');
        }

        $('.ui-tabs-nav').show();
      } else if ($('#small_nav').is(':visible'))
          $('.ui-tabs-nav').hide();
    });
}

function setUserId() {
  var paymentHREFhref = 'https://getadblock.com/pay/?source=O&u=' + BG.STATS.userId();
  $('#paymentlink').attr('href', paymentHREFhref);
}

function displayTranslationCredit(language) {
  if (language.substring(0, 2) != 'en') {
    var translators = [];
    var xhr = new XMLHttpRequest();
    xhr.open('GET', '../translators.json', true);
    xhr.onload = function () {
        var partialLang = language.substring(0, 2);
        var chromeLang = partialLang + '-' + partialLang;
        var text = JSON.parse(xhr.responseText);
        var matchFound = false;

        for (var id in text) {
          // if matching id hasn't been found and id matches lang
          if (!matchFound && (partialLang === id || chromeLang === id || language === id)) {
            matchFound = true;
            // Check if this language is professionally translated
            var professionalLang = text[id].professional;
            for (var translator in text[id].translators) {
              // If the language is not professionally translated, or if this translator
              // is a professional, then add the name to the list of credits
              if (!professionalLang || text[id].translators[translator].professional) {
                var name = text[id].translators[translator].credit;
                translators.push(' ' + name);
              }
            }
          }
        }

        if (translators.length > 0) {
          $('#translator_credit').text(translate('translator_credit'));
          $('#translator_names').text(translators.toString());
        }
      };

    xhr.send();
  }
}

function displayVersionNumber() {
  $('#version_number').text(translate('optionsversion', [BG.chrome.runtime.getManifest().version]));
}

var optionalSettings = {};
$(document).ready(function () {
  var lang = BG.getActiveLanguage();
  initializeLangData().then(function() {
    loadOptions();
    rightToLeft(lang);
    showMiniMenu(lang);
    setUserId();
    displayVersionNumber();
    displayTranslationCredit(lang);
  });
});
